Campmor: Contact Us

Backpack: 0 item(s) subtotal: $0.00
Your backpack is empty.

1-800-226-7667 |
What can we help you find? Press the access key plus 0 to focus on the search box
| 20% OFF ONE FULL PRICE ITEM. One Time Use Not valid on clearance items or items ending in .96 and SUP paddle boards. Some brand exclusions apply: Garmin GoPro Hobie Mountain Hardwear Outdoor Research Patagonia Pearl Izumi Thorlos Sierra Designs Sorel UGG Cannot be combined with other offers. Not Valid on Holiday Specials. Online Only. Not valid in retail store or on retail store pricing. Close |

Close

### Got a question or comment for us?

Give us a call or email us, we're ready to listen!

So that we can provide you with the best possible service, please provide us with the following information. We will not be able to contact you without a valid e-mail address. Campmor Customer Service will respond by the next business day.

* Required field

* Name |  |  |
* Email |  |  |
* Subject |  |  |
* Message |  |  |
* Daytime Phone |  |  |

Call 1-800-525-4784 during the following hours (Eastern Time): Mon.-Fri. 8:00am - 8:00pm Sat. 9:00am - 5:00pm
Customer Service is closed Sundays, Memorial Day, Independence Day, Labor Day, Thanksgiving, Christmas, and New Years Day.
Overseas? Call us at (201) 335-9064.